# Spine Items

[![Unit tests](https://github.com/spine-tools/spine-items/workflows/Unit%20tests/badge.svg)](https://github.com/spine-tools/spine-items/actions?query=workflow%3A"Unit+tests")
[![codecov](https://codecov.io/gh/spine-tools/spine-items/branch/master/graph/badge.svg)](https://codecov.io/gh/spine-tools/spine-items)
[![PyPI version](https://badge.fury.io/py/spine-items.svg)](https://badge.fury.io/py/spine-items)

A Python package to supply project items for [Spine Toolbox](https://github.com/spine-tools/Spine-Toolbox) and [Spine Engine](https://github.com/spine-tools/spine-engine).

## License

Spine Items is released under the GNU Lesser General Public License (LGPL) license. All accompanying
documentation and manual are released under the [Creative Commons BY-SA 4.0 license](https://creativecommons.org/licenses/by-sa/4.0/).

## Getting started

### Installation

Spine Items is not meant to be used as a stand-alone package.
You probably want to [install Spine Toolbox instead](https://github.com/spine-tools/Spine-Toolbox#installation).


&nbsp;
<hr>
<table width=500px frame="none">
<tr>
<td valign="middle" width=100px>
<img src=fig/eu-emblem-low-res.jpg alt="EU emblem" width=100%></td>
<td valign="middle">This project has received funding from European Climate, Infrastructure and Environment Executive Agency under the European Union’s HORIZON Research and Innovation Actions under grant agreement N°101095998.</td>
<tr>
<td valign="middle" width=100px>
<img src=fig/eu-emblem-low-res.jpg alt="EU emblem" width=100%></td>
<td valign="middle">This project has received funding from the European Union’s Horizon 2020 research and innovation programme under grant agreement No 774629.</td>
</table>
